==> jc-1.4.0.tar.gz: javax/print/DocFlavor__24URL.h <==
// public class javax.print.DocFlavor$URL

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class a95dbf9c9d048d51 javax_print_DocFlavor
// @dep_class 93fe1643647a4db9 javax_print_DocFlavor__24URL

// header file dependencies
// @dep_header javax_print_DocFlavor

#include "javax/print/DocFlavor.h"

#ifndef _JC_javax_print_DocFlavor__24URL_H_
#define _JC_javax_print_DocFlavor__24URL_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_javax_print_DocFlavor__24URL$object;

// Typedefs
typedef struct _jc_javax_print_DocFlavor__24URL$sub_refs	_jc_javax_print_DocFlavor__24URL$sub_refs;
typedef struct _jc_javax_print_DocFlavor__24URL$sub_nonrefs	_jc_javax_print_DocFlavor__24URL$sub_nonrefs;
typedef struct _jc_javax_print_DocFlavor__24URL$refs	_jc_javax_print_DocFlavor__24URL$refs;
typedef struct _jc_javax_print_DocFlavor__24URL$nonrefs	_jc_javax_print_DocFlavor__24URL$nonrefs;
typedef struct _jc_javax_print_DocFlavor__24URL$object	_jc_javax_print_DocFlavor__24URL$object;

typedef struct _jc_javax_print_DocFlavor__24URL$fields_struct	_jc_javax_print_DocFlavor__24URL$fields_struct;
typedef const struct _jc_javax_print_DocFlavor__24URL$vmethods	_jc_javax_print_DocFlavor__24URL$vmethods;
typedef const struct _jc_javax_print_DocFlavor__24URL$vtable	_jc_javax_print_DocFlavor__24URL$vtable;
typedef const struct _jc_javax_print_DocFlavor__24URL$vtype	_jc_javax_print_DocFlavor__24URL$vtype;

// Class fields structure
struct _jc_javax_print_DocFlavor__24URL$fields_struct {
	struct _jc_javax_print_DocFlavor__24URL$object	*AUTOSENSE;
	struct _jc_javax_print_DocFlavor__24URL$object	*GIF;
	struct _jc_javax_print_DocFlavor__24URL$object	*JPEG;
	struct _jc_javax_print_DocFlavor__24URL$object	*PCL;
	struct _jc_javax_print_DocFlavor__24URL$object	*PDF;
	struct _jc_javax_print_DocFlavor__24URL$object	*PNG;
	struct _jc_javax_print_DocFlavor__24URL$object	*POSTSCRIPT;
	struct _jc_javax_print_DocFlavor__24URL$object	*TEXT__5fHTML__5fHOST;
	struct _jc_javax_print_DocFlavor__24URL$object	*TEXT__5fHTML__5fUS__5fASCII;
	struct _jc_javax_print_DocFlavor__24URL$object	*TEXT__5fHTML__5fUTF__5f16;
	struct _jc_javax_print_DocFlavor__24URL$object	*TEXT__5fHTML__5fUTF__5f16BE;
	struct _jc_javax_print_DocFlavor__24URL$object	*TEXT__5fHTML__5fUTF__5f16LE;
	struct _jc_javax_print_DocFlavor__24URL$object	*TEXT__5fHTML__5fUTF__5f8;
	struct _jc_javax_print_DocFlavor__24URL$object	*TEXT__5fPLAIN__5fHOST;
	struct _jc_javax_print_DocFlavor__24URL$object	*TEXT__5fPLAIN__5fUS__5fASCII;
	struct _jc_javax_print_DocFlavor__24URL$object	*TEXT__5fPLAIN__5fUTF__5f16;
	struct _jc_javax_print_DocFlavor__24URL$object	*TEXT__5fPLAIN__5fUTF__5f16BE;
	struct _jc_javax_print_DocFlavor__24URL$object	*TEXT__5fPLAIN__5fUTF__5f16LE;
	struct _jc_javax_print_DocFlavor__24URL$object	*TEXT__5fPLAIN__5fUTF__5f8;
	jlong	serialVersionUID;
};
extern _jc_javax_print_DocFlavor__24URL$fields_struct _jc_javax_print_DocFlavor__24URL$class_fields;

// Constructors
extern void _jc_javax_print_DocFlavor__24URL$method$_init$c31b894660454d13(_jc_env *, struct _jc_javax_print_DocFlavor__24URL$object *, struct _jc_java_lang_String$object *);

// Static methods
extern void _jc_javax_print_DocFlavor__24URL$method$_clinit$a816641e0ba8bfef(_jc_env *);

// Virtual methods structure
struct _jc_javax_print_DocFlavor__24URL$vmethods {
};

// Vtable
struct _jc_javax_print_DocFlavor__24URL$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_print_DocFlavor$vmethods	javax_print_DocFlavor;
	_jc_javax_print_DocFlavor__24URL$vmethods	javax_print_DocFlavor__24URL;
};

// Vtype
struct _jc_javax_print_DocFlavor__24URL$vtype {
	_jc_type			type;
	_jc_javax_print_DocFlavor__24URL$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_print_DocFlavor__24URL$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_print_DocFlavor__24URL$refs {
    _jc_javax_print_DocFlavor__24URL$sub_refs	javax_print_DocFlavor__24URL;
    _jc_javax_print_DocFlavor$sub_refs	javax_print_DocFlavor;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_print_DocFlavor__24URL$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_print_DocFlavor__24URL$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_print_DocFlavor$sub_nonrefs	javax_print_DocFlavor;
    _jc_javax_print_DocFlavor__24URL$sub_nonrefs	javax_print_DocFlavor__24URL;
};

// Object instance structure
struct _jc_javax_print_DocFlavor__24URL$object {
	_jc_javax_print_DocFlavor__24URL$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_print_DocFlavor__24URL$vtype	*vtype;
	_jc_javax_print_DocFlavor__24URL$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_print_DocFlavor__24URL$vtype _jc_javax_print_DocFlavor__24URL$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_print_DocFlavor__24URL, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_print_DocFlavor__24URL$class_object;

#endif	/* _JC_javax_print_DocFlavor__24URL_H_ */

==> jc-1.4.6.tar.gz: javax/print/DocFlavor__24URL.h <==
// public class javax.print.DocFlavor$URL

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class a95dbf9c9d048d51 javax_print_DocFlavor
// @dep_class 93fe1643647a4db9 javax_print_DocFlavor__24URL

// header file dependencies
// @dep_header javax_print_DocFlavor

#include "javax/print/DocFlavor.h"

#ifndef _JC_javax_print_DocFlavor__24URL_H_
#define _JC_javax_print_DocFlavor__24URL_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_javax_print_DocFlavor__24URL$object;

// Typedefs
typedef struct _jc_javax_print_DocFlavor__24URL$sub_refs	_jc_javax_print_DocFlavor__24URL$sub_refs;
typedef struct _jc_javax_print_DocFlavor__24URL$sub_nonrefs	_jc_javax_print_DocFlavor__24URL$sub_nonrefs;
typedef struct _jc_javax_print_DocFlavor__24URL$refs	_jc_javax_print_DocFlavor__24URL$refs;
typedef struct _jc_javax_print_DocFlavor__24URL$nonrefs	_jc_javax_print_DocFlavor__24URL$nonrefs;
typedef struct _jc_javax_print_DocFlavor__24URL$object	_jc_javax_print_DocFlavor__24URL$object;

typedef struct _jc_javax_print_DocFlavor__24URL$fields_struct	_jc_javax_print_DocFlavor__24URL$fields_struct;
typedef const struct _jc_javax_print_DocFlavor__24URL$vmethods	_jc_javax_print_DocFlavor__24URL$vmethods;
typedef const struct _jc_javax_print_DocFlavor__24URL$vtable	_jc_javax_print_DocFlavor__24URL$vtable;
typedef const struct _jc_javax_print_DocFlavor__24URL$vtype	_jc_javax_print_DocFlavor__24URL$vtype;

// Class fields structure
struct _jc_javax_print_DocFlavor__24URL$fields_struct {
	struct _jc_javax_print_DocFlavor__24URL$object	*AUTOSENSE;
	struct _jc_javax_print_DocFlavor__24URL$object	*GIF;
	struct _jc_javax_print_DocFlavor__24URL$object	*JPEG;
	struct _jc_javax_print_DocFlavor__24URL$object	*PCL;
	struct _jc_javax_print_DocFlavor__24URL$object	*PDF;
	struct _jc_javax_print_DocFlavor__24URL$object	*PNG;
	struct _jc_javax_print_DocFlavor__24URL$object	*POSTSCRIPT;
	struct _jc_javax_print_DocFlavor__24URL$object	*TEXT__5fHTML__5fHOST;
	struct _jc_javax_print_DocFlavor__24URL$object	*TEXT__5fHTML__5fUS__5fASCII;
	struct _jc_javax_print_DocFlavor__24URL$object	*TEXT__5fHTML__5fUTF__5f16;
	struct _jc_javax_print_DocFlavor__24URL$object	*TEXT__5fHTML__5fUTF__5f16BE;
	struct _jc_javax_print_DocFlavor__24URL$object	*TEXT__5fHTML__5fUTF__5f16LE;
	struct _jc_javax_print_DocFlavor__24URL$object	*TEXT__5fHTML__5fUTF__5f8;
	struct _jc_javax_print_DocFlavor__24URL$object	*TEXT__5fPLAIN__5fHOST;
	struct _jc_javax_print_DocFlavor__24URL$object	*TEXT__5fPLAIN__5fUS__5fASCII;
	struct _jc_javax_print_DocFlavor__24URL$object	*TEXT__5fPLAIN__5fUTF__5f16;
	struct _jc_javax_print_DocFlavor__24URL$object	*TEXT__5fPLAIN__5fUTF__5f16BE;
	struct _jc_javax_print_DocFlavor__24URL$object	*TEXT__5fPLAIN__5fUTF__5f16LE;
	struct _jc_javax_print_DocFlavor__24URL$object	*TEXT__5fPLAIN__5fUTF__5f8;
	jlong	serialVersionUID;
};
extern _jc_javax_print_DocFlavor__24URL$fields_struct _jc_javax_print_DocFlavor__24URL$class_fields;

// Constructors
extern void _jc_javax_print_DocFlavor__24URL$method$_init$c31b894660454d13(_jc_env *, struct _jc_javax_print_DocFlavor__24URL$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Static methods
extern void _jc_javax_print_DocFlavor__24URL$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_print_DocFlavor__24URL$vmethods {
};

// Vtable
struct _jc_javax_print_DocFlavor__24URL$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_print_DocFlavor$vmethods	javax_print_DocFlavor;
	_jc_javax_print_DocFlavor__24URL$vmethods	javax_print_DocFlavor__24URL;
};

// Vtype
struct _jc_javax_print_DocFlavor__24URL$vtype {
	_jc_type			type;
	_jc_javax_print_DocFlavor__24URL$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_print_DocFlavor__24URL$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_print_DocFlavor__24URL$refs {
    _jc_javax_print_DocFlavor__24URL$sub_refs	javax_print_DocFlavor__24URL;
    _jc_javax_print_DocFlavor$sub_refs	javax_print_DocFlavor;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_print_DocFlavor__24URL$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_print_DocFlavor__24URL$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_print_DocFlavor$sub_nonrefs	javax_print_DocFlavor;
    _jc_javax_print_DocFlavor__24URL$sub_nonrefs	javax_print_DocFlavor__24URL;
};

// Object instance structure
struct _jc_javax_print_DocFlavor__24URL$object {
	_jc_javax_print_DocFlavor__24URL$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_print_DocFlavor__24URL$vtype	*vtype;
	_jc_javax_print_DocFlavor__24URL$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_print_DocFlavor__24URL$vtype _jc_javax_print_DocFlavor__24URL$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_print_DocFlavor__24URL, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_print_DocFlavor__24URL$class_object;

#endif	/* _JC_javax_print_DocFlavor__24URL_H_ */
